fn datetime_to_timestamp_millis(
datetime: NaiveDateTime,
timezone: &Timezone,
) -> Result<i64>Expand description
Interprets a timezone-less datetime in the given timezone and returns the corresponding epoch timestamp in milliseconds.
fn datetime_to_timestamp_millis(
datetime: NaiveDateTime,
timezone: &Timezone,
) -> Result<i64>Interprets a timezone-less datetime in the given timezone and returns the corresponding epoch timestamp in milliseconds.